package com.totopia.server.modules.user.repository;

import com.totopia.server.modules.user.entity.UserEntity;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;

import java.util.Date;
import java.util.Optional;

public interface UserRepository extends JpaRepository<UserEntity, Long> {

  Optional<UserEntity> findByUsername(String username);

  Page<UserEntity> findByUsernameContainingIgnoreCase(String username, Pageable pageable);

  Boolean existsByEmail(String email);

  Optional<UserEntity> findByEmail(String email);

  Boolean existsByUsername(String username);

  Page<UserEntity> findAllByNickname(String nickName, Pageable pageable) throws Exception;

  // 접속 제한 상태 유저 리스트
  Page<UserEntity> findAllByBlockTrue(Pageable pageable) throws Exception;

  // 접속 제한 상태가 아닌 유저 리스트
  Page<UserEntity> findAllByBlockFalse(Pageable pageable) throws Exception;

  // // 어드민 유저 리스
  // Page<UserEntity> findAllByIsAdminTrue(Pageable pageable) throws Exception;

  // 패스워드 리셋이 트루인 유저 리스
  Page<UserEntity> findAllByRequireResetTrue(Pageable pageable) throws Exception;

  // // 어드민이 펄스이며, 활동중인 현재 회원 리스트
  // Page<UserEntity> findAllByIsAdminFalseAndActivationEquals(String activation,
  // Pageable pageable) throws Exception;

  // 날짜 검색
  Page<UserEntity> findAllByCreatedAtBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;

  Page<UserEntity> findAllByUpdatedAtBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;

  Page<UserEntity> findAllByLastResetTimeBetween(Date starDate, Date endDate, Pageable pageable) throws Exception;

  // 현재 날짜 이후 가입된 회원의 총 수 리턴
  Long countByCreatedAtGreaterThanEqual(Date date) throws Exception;

  // 유저 그룹별 회원 리스트

  // 유저 소속별 회원 리스트

}
